@@ -110,14 +110,25 @@ TAGS = [
     ("INF-WARNING", "orange"),
     ("LOG", "skyblue1"),
     ("MON", "skyblue1"),
+    ("NAV-AOPSTATUS", "yellow"),
+    ("NAV-COV", "yellow"),
     ("NAV-CLOCK", "cyan"),
+    ("NAV-DGPS", "yellow"),
     ("NAV-DOP", "mediumpurple2"),
+    ("NAV-EELL", "yellow"),
+    ("NAV-EOE", "yellow"),
+    ("NAV-GEOFENCE", "yellow"),
+    ("NAV-ODO", "deepskyblue"),
     ("NAV-ORB", "yellow"),
     ("NAV-POSECEF", "orange"),
     ("NAV-POSLLH", "orange"),
+    ("NAV-HPPOSECEF", "orange"),
+    ("NAV-HPPOSLLH", "orange"),
     ("NAV-PVT", "orange"),
     ("NAV-SAT", "yellow"),
     ("NAV-SBAS", "yellow"),
+    ("NAV-SIG", "yellow"),
+    ("NAV-SLAS", "yellow"),
     ("NAV-SOL", "green2"),
     ("NAV-STATUS", "green2"),
     ("NAV-SVINFO", "yellow"),
@@ -126,6 +137,7 @@ TAGS = [
     ("NAV-TIMEGLO", "cyan"),
     ("NAV-TIMEGPS", "cyan"),
     ("NAV-TIMELS", "cyan"),
+    ("NAV-TIMEQZSS", "cyan"),
     ("NAV-TIMEUTC", "cyan"),
     ("NAV-VELECEF", "deepskyblue"),
     ("NAV-VELNED", "deepskyblue"),
